import request from '../utils/request';

// 登录
export function solicLogin(data, config) {
    return request({
        url: '/tianzong/appSysUser/solic_login',
        method: 'post',
        data: data,
        ...config
    })
}

// 首页-扫码
export function appFindYourShipment(data, config) {
    return request({
        url: '/tianzong/express/appFindYourShipment',
        method: 'post',
        data: data,
        ...config
    })
}

// 快递出库-扫码
export function appDeliveryPersonDeliveries(data, config) {
    return request({
        url: '/tianzong/express/appDeliveryPersonDeliveries',
        method: 'post',
        data: data,
        ...config
    })
}

//快件入库-通过手机号后四位获取信息
export function appGetEmployeeInfoByPhone(data, config) {
    return request({
        url: '/tianzong/express/appGetEmployeeInfoByPhone',
        method: 'post',
        data: data,
        ...config
    })
}

//快件入库-快递物流配置列表
export function appGeLogisticsList(data, config) {
    return request({
        url: '/tianzong/express/appGeLogisticsList',
        method: 'post',
        data: data,
        ...config
    })
}

//快件入库-入库
export function appSaveExpressRecord(data, config) {
    return request({
        url: '/tianzong/express/appSaveExpressRecord',
        method: 'post',
        data: data,
        ...config
    })
}



//快件签收-快递单号查询
export function appFindYourShipmentList(data, config) {
    return request({
        url: '/tianzong/express/appFindYourShipmentList ',
        method: 'post',
        data: data,
        ...config
    })
}

//快件签收-图片上传
export function appUploadTheSignature(data) {
    return request({
        url: '/tianzong/express/appUploadTheSignature',
        method: 'post',
        data: data,
        // ...config
    })
}


//快件签收-提件
export function appDelivery(data, config) {
    return request({
        url: '/tianzong/express/appDelivery',
        method: 'post',
        data: data,
        emulateJSON: true,
        ...config
    })
}

//派件查询-设为滞留
export function appSetStrands(data, config) {
    return request({
        url: '/tianzong/express/appSetStrands',
        method: 'post',
        data: data,
        emulateJSON: true,
        ...config
    })
}



//派件查询-待派件
export function appOutboundInquiry(data, config) {
    return request({
        url: '/tianzong/express/appOutboundInquiry',
        method: 'post',
        data: data,
        ...config
    })
}


//派件查询-详情
export function appGetTheDetails(data, config) {
    return request({
        url: '/tianzong/express/appGetTheDetails',
        method: 'post',
        data: data,
        emulateJSON: true
    })
}

//数据图表
export function appStatistics(data) {
    return request({
        url: '/tianzong/express/appStatistics',
        method: 'post',
        data: data,
        emulateJSON: true
    })
}

//修改密码
export function LJYforgetPassword(data) {
    return request({
        url: '/tianzong/appSysUser/LJYforgetPassword',
        method: 'post',
        data: data,
        emulateJSON: true
    })
}

//获取信息
export function getSysUserInfoByUserIdAPI(data) {
    return request({
        url: '/tianzong/personal/getSysUserInfoByUserId.do',
        method: 'post',
        data: data,
        emulateJSON: true
    })
}


//获取微信
export function getWxConfig(data) {
    return request({
        url: '/tianzong/weixin/getWxConfig',
        method: 'post',
        data: data,
        emulateJSON: true
    })
}

//快件出库-调用扫码后的校验 - 如果返回为空-不在派送范围    
export function appPermissionChecks(data) {
    return request({
        url: '/tianzong/express/appPermissionChecks',
        method: 'post',
        data: data,
        emulateJSON: true
    })
}

// 首先获取打印机 判断打印机的数量，如果没有提示， 如果只有一个直接进入打印,如果有多个打印机弹框让用户选择然后在进入打印，
//获取打印机
export function getListOfPrinters(data) {
    return request({
        url: '/tianzong/printer/getListOfPrinters',
        method: 'post',
        data: data,
        emulateJSON: true
    })
}

// 入库打印标签
export function storagePrintSmallTab(data) {
    return request({
        url: '/tianzong/printer/storagePrintSmallTab',
        method: 'post',
        data: data,
        emulateJSON: true
    })
}

// 通过订单号查询内部件详情
export function appFindInsideInfoByExpressNo(data) {
    return request({
        url: '/tianzong/express/appFindInsideInfoByExpressNo',
        method: 'post',
        data: data,
        emulateJSON: true
    })
}

// 后带你生成的批次号
export function appGetLotNumber(data) {
    return request({
        url: '/tianzong/express/appGetLotNumber',
        method: 'post',
        data: data,
        emulateJSON: true
    })
}